==> hlaR_0.1.0.tar.gz: hlaR/R/globals.R <==
# global variables
utils::globalVariables(c("a", "a1", "allele","a1_mm", "a2", "a2_mm", "afa_freq", "afa_rank", "api_freq", "api_rank", "avg",
                         "b", "b1", "b1_mm", "b2", "b2_mm",
                         "c1", "c1_mm", "c2", "c2_mm", "cau_freq", "cau_rank", "clean1", "clean2", "cnt",
                         "cnt_a", "cnt_a_hi", "cnt_b", "cnt_b_hi", "cnt_c", "cnt_c_hi", "cnt_dqb1", "cnt_dqb1_hi",
                         "cnt_drb1", "cnt_drb1_hi", "cnt_drb3", "cnt_drb345", "cnt_drb345_hi", "cnt_drb3_hi",
                         "cnt_drb4", "cnt_drb4_hi", "cnt_drb5", "cnt_drb5_hi", "cnt_hi", "cnt_lo", "cnt_pair",
                         "d1", "d2", "dat_type", "don_a1", "don_a2", "don_b1", "don_b2", "don_c1", "don_c2", "don_dpa1",
                         "don_dpa2", "don_dpb1", "don_dpb2", "don_dqa1", "don_dqa2", "don_dqb1", "don_dqb2",
                         "don_drb1", "don_drb2", "don_drw1", "don_drw2", "dpa1_mm", "dpa2_mm", "dpb1_mm", "dpb1_tmp2",
                         "dpb1_tmp8", "dpb2_mm", "dpb2_tmp2", "dpb2_tmp8", "dqa1_mm", "dqa2_mm", "dqb1", "dqb1_mm",
                         "dqb2", "dqb2_mm", "drb", "drb1", "drb1_mm", "drb2", "drb2_mm", "drb31", "drb32", "drb345", "drb41",
                         "drb42", "drb51", "drb52", "drw1_mm", "drw2_mm", "dup_a", "dup_b", "dup_c", "dup_dqb1", "dup_drb1",
                         "dup_drb345",
                         "eplet", "ethnicity",
                         "freq", "fst_a", "fst_b", "fst_c", "fst_dqb1", "fst_drb1", "fst_drb345",
                         "gene", "his_freq",
                         "his_rank", "hla",
                         "idx", "index",
                         "locus", "locus1_clean", "locus2_clean",
                         "m1", "m2", "mism_1", "mism_2", "mm", "mm_cnt", "mm_cnt_tt", "mm_eplets",
                         "nam_freq", "nam_rank", "name", "num_nas",
                         "pair", "pair_id", "pair_id_ori", "part_type",
                         "rec_a1", "rec_a2", "rec_b1", "rec_b2", "rec_c1", "rec_c2", "rec_dpa1", "rec_dpa2", "rec_dpb1",
                         "rec_dpb2", "rec_dqa1", "rec_dqa2", "rec_dqb1", "rec_dqb2", "rec_drb1", "rec_drb2",
                         "rec_drw1", "rec_drw2", "rname",
                         "subj", "subject", "subject_type",
                         "type",
                         "v1", "v1.1", "v1.10", "v1.1st", "v1.1st.2", "v1.2", "v1.3", "v1.4", "v1.5", "v1.6", "v1.7", "v1.8",
                         "v1.9", "v1.last", "v1.last.2", "v2", "v2.1", "v2.10", "v2.1st", "v2.1st.2", "v2.2", "v2.3", "v2.4",
                         "v2.5", "v2.6", "v2.7", "v2.8", "v2.9", "v2.last", "v2.last.2", "value", "variable",
                         ".", ":="))

==> hlaR_0.1.1.tar.gz: hlaR/R/globals.R <==
# global variables
utils::globalVariables(c("a", "a1", "allele","a1_mm", "a2", "a2_mm", "afa_freq", "afa_rank", "api_freq", "api_rank", "avg",
                         "b", "b1", "b1_mm", "b2", "b2_mm",
                         "c1", "c1_mm", "c2", "c2_mm", "cau_freq", "cau_rank", "clean1", "clean2", "cnt",
                         "cnt_a", "cnt_a_hi", "cnt_b", "cnt_b_hi", "cnt_c", "cnt_c_hi", "cnt_dqb1", "cnt_dqb1_hi",
                         "cnt_drb1", "cnt_drb1_hi", "cnt_drb3", "cnt_drb345", "cnt_drb345_hi", "cnt_drb3_hi",
                         "cnt_drb4", "cnt_drb4_hi", "cnt_drb5", "cnt_drb5_hi", "cnt_hi", "cnt_lo", "cnt_pair",
                         "d1", "d2", "dat_type", "don_a1", "don_a2", "don_b1", "don_b2", "don_c1", "don_c2", "don_dpa1",
                         "don_dpa2", "don_dpb1", "don_dpb2", "don_dqa1", "don_dqa2", "don_dqb1", "don_dqb2",
                         "don_drb1", "don_drb2", "don_drw1", "don_drw2", "dpa1_mm", "dpa2_mm", "dpb1_mm", "dpb1_tmp2",
                         "dpb1_tmp8", "dpb2_mm", "dpb2_tmp2", "dpb2_tmp8", "dqa1_mm", "dqa2_mm", "dqb1", "dqb1_mm",
                         "dqb2", "dqb2_mm", "drb", "drb1", "drb1_mm", "drb2", "drb2_mm", "drb31", "drb32", "drb345", "drb41",
                         "drb42", "drb51", "drb52", "drw1_mm", "drw2_mm", "dup_a", "dup_b", "dup_c", "dup_dqb1", "dup_drb1",
                         "dup_drb345",
                         "eplet", "ethnicity",
                         "freq", "fst_a", "fst_b", "fst_c", "fst_dqb1", "fst_drb1", "fst_drb345",
                         "gene", "his_freq",
                         "his_rank", "hla",
                         "idx", "index",
                         "locus", "locus1_clean", "locus2_clean",
                         "m1", "m2", "mism_1", "mism_2", "mm", "mm_cnt", "mm_cnt_tt", "mm_eplets", "mm_pect",
                         "nam_freq", "nam_rank", "name", "num_nas",
                         "pair", "pair_id", "pair_id_ori", "part_type",
                         "rec_a1", "rec_a2", "rec_b1", "rec_b2", "rec_c1", "rec_c2", "rec_dpa1", "rec_dpa2", "rec_dpb1",
                         "rec_dpb2", "rec_dqa1", "rec_dqa2", "rec_dqb1", "rec_dqb2", "rec_drb1", "rec_drb2",
                         "rec_drw1", "rec_drw2", "rname",
                         "rn", "1", "12", "mm_cn_uniq",
                         "subj", "subject", "subject_type", "type", "var",
                         "v1", "v1.1", "v1.0", "v1.11", "v2.0", "v2.11", "v1.10", "v1.1st", "v1.1st.2", "v1.2", "v1.3", "v1.4", "v1.5", "v1.6", "v1.7", "v1.8",
                         "v1.9", "v1.last", "v1.last.2", "v2", "v2.1", "v2.10", "v2.1st", "v2.1st.2", "v2.2", "v2.3", "v2.4",
                         "v2.5", "v2.6", "v2.7", "v2.8", "v2.9", "v2.last", "v2.last.2", "value", "variable",
                         ".", ":=",
                         "cnt_match_by_pair", "dqb1.1", "dqb1.2", "drb1.1", "drb1.2", "drb3.1", "drb3.2", "drb4.1",
                         "drb4.2", "drb5.1", "drb5.2", "flag", "grp", "lores_all_match", "rnum"))
